deg(x, spec, a = 1, b = 1, log = FALSE, ...)
peg(x, spec, a = 1, b = 1, log.p = FALSE, lower.tail = TRUE, ...)
qeg(p, spec, a = 1, b = 1, log.p = FALSE, lower.tail = TRUE, ...)
reg(n, spec, a = 1, b = 1, ...)x, giving the pdf or cdf values computed at x or an object of the same length as p, giving the quantile values computed at p or an object of the same length as n, giving the random numbers generated.x=runif(10,min=0,max=1)
deg(x,"exp",a=1,b=1)
peg(x,"exp",a=1,b=1)
qeg(x,"exp",a=1,b=1)
reg(10,"exp",a=1,b=1)Run the code above in your browser using DataLab