dgammag(x, spec, a = 1, log = FALSE, ...)
pgammag(x, spec, a = 1, log.p = FALSE, lower.tail = TRUE, ...)
qgammag(p, spec, a = 1, log.p = FALSE, lower.tail = TRUE, ...)
rgammag(n, spec, a = 1, ...)x, giving the pdf or cdf values computed at x or an object of the same length as p, giving the quantile values computed at p or an object of the same length as n, giving the random numbers generated.x=runif(10,min=0,max=1)
dgammag(x,"exp",a=1)
pgammag(x,"exp",a=1)
qgammag(x,"exp",a=1)
rgammag(10,"exp",a=1)Run the code above in your browser using DataLab