dmbetag(x, spec, beta = 1, a = 1, b = 1, log = FALSE, ...)
pmbetag(x, spec, beta = 1, a = 1, b = 1, log.p = FALSE, lower.tail = TRUE, ...)
qmbetag(p, spec, beta = 1, a = 1, b = 1, log.p = FALSE, lower.tail = TRUE, ...)
rmbetag(n, spec, beta = 1, a = 1, b = 1, ...)x, giving the pdf or cdf values computed at x or an object of the same length as p, giving the quantile values computed at p or an object of the same length as n, giving the random numbers generated.x=runif(10,min=0,max=1)
dmbetag(x,"exp",beta=1,a=1,b=1)
pmbetag(x,"exp",beta=1,a=1,b=1)
qmbetag(x,"exp",beta=1,a=1,b=1)
rmbetag(10,"exp",beta=1,a=1,b=1)Run the code above in your browser using DataLab